==> prometheus-annotations-2.8.1-sources.jar: io/dekorate/prometheus/model/ServiceMonitorBuilder.java <==
package io.dekorate.prometheus.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceMonitorBuilder extends io.dekorate.prometheus.model.ServiceMonitorFluentImpl<io.dekorate.prometheus.model.ServiceMonitorBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.dekorate.prometheus.model.ServiceMonitor,io.dekorate.prometheus.model.ServiceMonitorBuilder>{
  public ServiceMonitorBuilder() {
    this(false);
  }
  public ServiceMonitorBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceMonitor(), validationEnabled);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceMonitor(), validationEnabled);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,io.dekorate.prometheus.model.ServiceMonitor instance) {
    this(fluent, instance, false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,io.dekorate.prometheus.model.ServiceMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitor instance) {
    this(instance,false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.prometheus.model.ServiceMonitor build() {
    ServiceMonitor buildable = new ServiceMonitor(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceMonitorBuilder that = (ServiceMonitorBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> prometheus-annotations-2.11.4-sources.jar: io/dekorate/prometheus/model/ServiceMonitorBuilder.java <==
package io.dekorate.prometheus.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceMonitorBuilder extends ServiceMonitorFluentImpl<ServiceMonitorBuilder> implements VisitableBuilder<io.dekorate.prometheus.model.ServiceMonitor,io.dekorate.prometheus.model.ServiceMonitorBuilder>{
  public ServiceMonitorBuilder() {
    this(false);
  }
  public ServiceMonitorBuilder(Boolean validationEnabled) {
    this(new ServiceMonitor(), validationEnabled);
  }
  public ServiceMonitorBuilder(ServiceMonitorFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceMonitor(), validationEnabled);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,io.dekorate.prometheus.model.ServiceMonitor instance) {
    this(fluent, instance, false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent,io.dekorate.prometheus.model.ServiceMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitor instance) {
    this(instance,false);
  }
  public ServiceMonitorBuilder(io.dekorate.prometheus.model.ServiceMonitor instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withAdditionalProperties(instance.getAdditionalProperties()); 
    this.validationEnabled = validationEnabled; 
  }
  io.dekorate.prometheus.model.ServiceMonitorFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.dekorate.prometheus.model.ServiceMonitor build() {
    ServiceMonitor buildable = new ServiceMonitor(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getAdditionalProperties());
    return buildable;
  }
  
}
